{# PARENT DIV IS REQUIRED HERE WITH html-field-wrapper CLASS. DON'T REMOVE IT #}
<div class="waf--html-field-wrapper" data-waf-field>
    <div id="waf--html-field-{{ widget.name }}">
        {{ widget.html_value }}
    </div>
</div>

