# Generated by Django 3.2 on 2023-04-27 11:08

from django.db import migrations, models
import wagtail.blocks
import wagtail.contrib.forms.models
import wagtail.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_advanced_form_builder', '0002_auto_20201116_2241'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailformfield',
            name='choices',
            field=models.TextField(blank=True, help_text='Comma or new line separated list of choices. Only applicable in checkboxes, radio and dropdown.', verbose_name='choices'),
        ),
        migrations.AlterField(
            model_name='emailformfield',
            name='default_value',
            field=models.TextField(blank=True, help_text='Default value. Comma or new line separated values supported for checkboxes.', verbose_name='default value'),
        ),
        migrations.AlterField(
            model_name='emailformpage',
            name='form',
            field=wagtail.fields.StreamField([('singleline', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Basic field')), ('email', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Email field')), ('html', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='A unique reference for this html block', label='Unique reference name', max_length=255, required=True)), ('html', wagtail.blocks.RichTextBlock(required=True)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='HTML')), ('dropdown', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('empty_label', wagtail.blocks.CharBlock(max_length=255, required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Dropdown field')), ('radio', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Radio field')), ('checkboxes', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(help_text='Enter a value that matches a checkbox choice above to have it ticked by default.', icon='extraicons--heading-icon', required=False))), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkboxes field')), ('checkbox', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('display_checkbox_label', wagtail.blocks.BooleanBlock(default=False, help_text='Do you want the checkbox label to display? If not you should populate help_text.', required=False)), ('help_text', wagtail.blocks.CharBlock(max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkbox field')), ('multiselect', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiselect field')), ('multiline', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiline field')), ('url', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='URL field')), ('hidden', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('default_value', wagtail.blocks.CharBlock(help_text='The value to go into the hidden field.', label='Value', max_length=255, required=True))], label='Hidden field')), ('number', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Number field'))], default=None, help_text='Add fields to the form', null=True, use_json_field=True),
        ),
        migrations.AlterField(
            model_name='emailformpage',
            name='from_address',
            field=models.EmailField(blank=True, max_length=255, verbose_name='from address'),
        ),
        migrations.AlterField(
            model_name='emailformpage',
            name='to_address',
            field=models.CharField(blank=True, help_text='Optional - form submissions will be emailed to these addresses. Separate multiple addresses by comma.', max_length=255, validators=[wagtail.contrib.forms.models.validate_to_address], verbose_name='to address'),
        ),
        migrations.AlterField(
            model_name='formfield',
            name='choices',
            field=models.TextField(blank=True, help_text='Comma or new line separated list of choices. Only applicable in checkboxes, radio and dropdown.', verbose_name='choices'),
        ),
        migrations.AlterField(
            model_name='formfield',
            name='default_value',
            field=models.TextField(blank=True, help_text='Default value. Comma or new line separated values supported for checkboxes.', verbose_name='default value'),
        ),
        migrations.AlterField(
            model_name='formpage',
            name='form',
            field=wagtail.fields.StreamField([('singleline', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Basic field')), ('email', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Email field')), ('html', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='A unique reference for this html block', label='Unique reference name', max_length=255, required=True)), ('html', wagtail.blocks.RichTextBlock(required=True)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='HTML')), ('dropdown', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('empty_label', wagtail.blocks.CharBlock(max_length=255, required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Dropdown field')), ('radio', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Radio field')), ('checkboxes', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(help_text='Enter a value that matches a checkbox choice above to have it ticked by default.', icon='extraicons--heading-icon', required=False))), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkboxes field')), ('checkbox', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('display_checkbox_label', wagtail.blocks.BooleanBlock(default=False, help_text='Do you want the checkbox label to display? If not you should populate help_text.', required=False)), ('help_text', wagtail.blocks.CharBlock(max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkbox field')), ('multiselect', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.blocks.ListBlock(wagtail.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiselect field')), ('multiline', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiline field')), ('url', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='URL field')), ('hidden', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('default_value', wagtail.blocks.CharBlock(help_text='The value to go into the hidden field.', label='Value', max_length=255, required=True))], label='Hidden field')), ('number', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.blocks.StructBlock([('action', wagtail.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.blocks.StreamBlock([('condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.blocks.StructBlock([('field_name', wagtail.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Number field'))], default=None, help_text='Add fields to the form', null=True, use_json_field=True),
        ),
    ]
